@@ -135,7 +135,7 @@ typedef struct
 #define HOSTNAME_LOOKUP_EXPIRE 	300
 
 /* wait 30 seconds between connection and receiving data on the line */
-#define CONNECTION_TIMEOUT      30
+#define CONNECTION_TIMEOUT_SEC  30
 
 enum
 {
@@ -502,8 +502,8 @@ gdict_client_context_finalize (GObject *object)
 
 /**
  * gdict_client_context_new:
- * @hostname: the hostname of a dictionary server, or %NULL for the
- *    default server
+ * @hostname: (nullable): the hostname of a dictionary server,
+ *    or %NULL for the default server
  * @port: port to be used when connecting to the dictionary server,
  *    or -1 for the default port
  *
@@ -511,8 +511,7 @@ gdict_client_context_finalize (GObject *object)
  * object to connect and query the dictionary server using the Dictionary
  * Protocol as defined by RFC 2229.
  *
- * Return value: the newly created #GdictClientContext object.  You should
- *   free it using g_object_unref().
+ * Return value: (transfer full): the newly created #GdictClientContext object.
  */
 GdictContext *
 gdict_client_context_new (const gchar *hostname,
@@ -528,7 +527,7 @@ gdict_client_context_new (const gchar *hostname,
 /**
  * gdict_client_context_set_hostname:
  * @context: a #GdictClientContext
- * @hostname: the hostname of a Dictionary server, or %NULL
+ * @hostname: (nullable): the hostname of a Dictionary server, or %NULL
  *
  * Sets @hostname as the hostname of the dictionary server to be used.
  * If @hostname is %NULL, the default dictionary server will be used.
@@ -609,7 +608,7 @@ gdict_client_context_get_port (GdictClientContext *context)
 /**
  * gdict_client_context_set_client:
  * @context: a #GdictClientContext
- * @client: the client name to use, or %NULL
+ * @client: (nullable): the client name to use, or %NULL
  *
  * Sets @client as the client name to be used when advertising ourselves when
  * a connection the the dictionary server has been established.
@@ -1394,8 +1393,6 @@ gdict_client_context_parse_line (GdictClientContext *context,
             p = g_utf8_next_char (p);
           
           GDICT_NOTE (DICT, "server replied: %d databases found", atoi (p));
-          
-          g_signal_emit_by_name (context, "lookup-start");
         }
       else if (0 == strcmp (buffer, "."))
         priv->command->state = S_FINISH;
@@ -1446,8 +1443,6 @@ gdict_client_context_parse_line (GdictClientContext *context,
             p = g_utf8_next_char (p);
           
           GDICT_NOTE (DICT, "server replied: %d strategies found", atoi (p));
-          
-          g_signal_emit_by_name (context, "lookup-start");
         }
       else if (0 == strcmp (buffer, "."))
         priv->command->state = S_FINISH;
@@ -1501,8 +1496,6 @@ gdict_client_context_parse_line (GdictClientContext *context,
           
           priv->command->data = def;
           priv->command->data_destroy = (GDestroyNotify) gdict_definition_unref;
-
-          g_signal_emit_by_name (context, "lookup-start");
         }
       else if (priv->status_code == GDICT_STATUS_WORD_DB_NAME)
         {
@@ -1610,8 +1603,6 @@ gdict_client_context_parse_line (GdictClientContext *context,
             p = g_utf8_next_char (p);
           
           GDICT_NOTE (DICT, "server replied: %d matches found", atoi (p));
-
-          g_signal_emit_by_name (context, "lookup-start");
         }
       else if (0 == strcmp (buffer, "."))
         priv->command->state = S_FINISH;
@@ -1989,9 +1980,9 @@ gdict_client_context_connect (GdictClientContext  *context,
       return FALSE;
     }
 
-  priv->timeout_id = g_timeout_add (CONNECTION_TIMEOUT * 1000,
-                                    check_for_connection,
-                                    context);
+  priv->timeout_id = g_timeout_add_seconds (CONNECTION_TIMEOUT_SEC,
+                                            check_for_connection,
+                                            context);
   
   /* XXX - remember that g_io_add_watch() increases the reference count
    * of the GIOChannel we are using.
@@ -2044,6 +2035,8 @@ gdict_client_context_get_databases (GdictContext  *context,
   g_return_val_if_fail (GDICT_IS_CLIENT_CONTEXT (context), FALSE);
   
   client_ctx = GDICT_CLIENT_CONTEXT (context);
+
+  g_signal_emit_by_name (context, "lookup-start");
   
   if (!gdict_client_context_is_connected (client_ctx))
     {
@@ -2052,6 +2045,8 @@ gdict_client_context_get_databases (GdictContext  *context,
       gdict_client_context_connect (client_ctx, &connect_error);
       if (connect_error)
         {
+          g_signal_emit_by_name (context, "lookup-end");
+
           g_propagate_error (error, connect_error);
           
           return FALSE;
@@ -2073,6 +2068,8 @@ gdict_client_context_get_strategies (GdictContext  *context,
   g_return_val_if_fail (GDICT_IS_CLIENT_CONTEXT (context), FALSE);
   
   client_ctx = GDICT_CLIENT_CONTEXT (context);
+
+  g_signal_emit_by_name (context, "lookup-start");
   
   if (!gdict_client_context_is_connected (client_ctx))
     {
@@ -2081,6 +2078,8 @@ gdict_client_context_get_strategies (GdictContext  *context,
       gdict_client_context_connect (client_ctx, &connect_error);
       if (connect_error)
         {
+          g_signal_emit_by_name (context, "lookup-end");
+
           g_propagate_error (error, connect_error);
           
           return FALSE;
@@ -2104,6 +2103,8 @@ gdict_client_context_define_word (GdictContext  *context,
   g_return_val_if_fail (GDICT_IS_CLIENT_CONTEXT (context), FALSE);
 
   client_ctx = GDICT_CLIENT_CONTEXT (context);
+
+  g_signal_emit_by_name (context, "lookup-start");
   
   if (!gdict_client_context_is_connected (client_ctx))
     {
@@ -2112,6 +2113,8 @@ gdict_client_context_define_word (GdictContext  *context,
       gdict_client_context_connect (client_ctx, &connect_error);
       if (connect_error)
         {
+          g_signal_emit_by_name (context, "lookup-end");
+
           g_propagate_error (error, connect_error);
           
           return FALSE;
@@ -2138,6 +2141,8 @@ gdict_client_context_match_word (GdictContext  *context,
   g_return_val_if_fail (GDICT_IS_CLIENT_CONTEXT (context), FALSE);
 
   client_ctx = GDICT_CLIENT_CONTEXT (context);
+
+  g_signal_emit_by_name (context, "lookup-start");
   
   if (!gdict_client_context_is_connected (client_ctx))
     {
@@ -2146,6 +2151,8 @@ gdict_client_context_match_word (GdictContext  *context,
       gdict_client_context_connect (client_ctx, &connect_error);
       if (connect_error)
         {
+          g_signal_emit_by_name (context, "lookup-end");
+
           g_propagate_error (error, connect_error);
           
           return FALSE;
