@@ -39,7 +39,7 @@
 #include "gdict-pref-dialog.h"
 #include "gdict-common.h"
 
-#define GDICT_PREFERENCES_UI 	PKGDATADIR "/gnome-dictionary-preferences.ui"
+#define GDICT_PREFERENCES_UI 	"/org/gnome/Dictionary/gnome-dictionary-preferences.ui"
 
 #define DEFAULT_MIN_WIDTH 	220
 #define DEFAULT_MIN_HEIGHT 	330
@@ -385,24 +385,16 @@ source_remove_clicked_cb (GtkWidget       *widget,
       						_("This will permanently remove the "
       						  "dictionary source from the list."));
       
-      gtk_dialog_add_button (GTK_DIALOG (confirm_dialog),
-      			     GTK_STOCK_CANCEL,
-      			     GTK_RESPONSE_CANCEL);
-      gtk_dialog_add_button (GTK_DIALOG (confirm_dialog),
-      			     GTK_STOCK_REMOVE,
-      			     GTK_RESPONSE_OK);
+      gtk_dialog_add_button (GTK_DIALOG (confirm_dialog), _("_Cancel"), GTK_RESPONSE_CANCEL);
+      gtk_dialog_add_button (GTK_DIALOG (confirm_dialog), _("_Remove"), GTK_RESPONSE_OK);
       
       gtk_window_set_title (GTK_WINDOW (confirm_dialog), "");
       
       response = gtk_dialog_run (GTK_DIALOG (confirm_dialog));
-      if (response == GTK_RESPONSE_CANCEL)
-        {
-          gtk_widget_destroy (confirm_dialog);
-          
-          goto out;
-        }
-      
       gtk_widget_destroy (confirm_dialog);
+
+      if (response == GTK_RESPONSE_CANCEL)
+        goto out;
     }
   
   if (gdict_source_loader_remove_source (dialog->loader, name))
@@ -630,7 +622,6 @@ static void
 gdict_pref_dialog_init (GdictPrefDialog *dialog)
 {
   gchar *font;
-  GError *error = NULL;
 
   gtk_window_set_default_size (GTK_WINDOW (dialog),
   			       DEFAULT_MIN_WIDTH,
@@ -651,13 +642,7 @@ gdict_pref_dialog_init (GdictPrefDialog *dialog)
 
   /* get the UI from the GtkBuilder file */
   dialog->builder = gtk_builder_new ();
-  gtk_builder_add_from_file (dialog->builder, GDICT_PREFERENCES_UI, &error);
-
-  if (error) {
-    g_critical ("Unable to load the preferences user interface: %s", error->message);
-    g_error_free (error);
-    g_assert_not_reached ();
-  }
+  gtk_builder_add_from_resource (dialog->builder, GDICT_PREFERENCES_UI, NULL);
 
   /* the main widget */
   gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
