@@ -38,7 +38,7 @@
 #include "gdict-source-dialog.h"
 #include "gdict-common.h"
 
-#define GDICT_SOURCE_UI 	PKGDATADIR "/gnome-dictionary-source.ui"
+#define GDICT_SOURCE_UI 	"/org/gnome/Dictionary/gnome-dictionary-source.ui"
 
 /*********************
  * GdictSourceDialog *
@@ -574,7 +574,6 @@ gdict_source_dialog_constructor (GType                  type,
   GObject *object;
   GdictSourceDialog *dialog;
   GtkWidget *vbox;
-  GError *error = NULL;
 
   object = G_OBJECT_CLASS (gdict_source_dialog_parent_class)->constructor (type,
 									   n_construct_properties,
@@ -584,18 +583,9 @@ gdict_source_dialog_constructor (GType                  type,
   gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dialog))), 2);
   
-  gtk_widget_push_composite_child ();
-
   /* get the UI from the GtkBuilder file */
   dialog->builder = gtk_builder_new ();
-  gtk_builder_add_from_file (dialog->builder, GDICT_SOURCE_UI, &error);
-
-  if (error) {
-    g_critical ("Unable to load the user interface definition file: %s",
-                error->message);
-    g_error_free (error);
-    g_assert_not_reached ();
-  }
+  gtk_builder_add_from_resource (dialog->builder, GDICT_SOURCE_UI, NULL);
   
   /* the main widget */
   gtk_container_add (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))),
@@ -610,9 +600,7 @@ gdict_source_dialog_constructor (GType                  type,
   		    dialog);
 
   /* the help button is always visible */
-  dialog->help_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-  					       GTK_STOCK_HELP,
-					       GTK_RESPONSE_HELP);
+  dialog->help_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Help"), GTK_RESPONSE_HELP);
   
   vbox = GTK_WIDGET (gtk_builder_get_object (dialog->builder, "db-vbox"));
   dialog->db_chooser = gdict_database_chooser_new ();
@@ -638,29 +626,19 @@ gdict_source_dialog_constructor (GType                  type,
       gtk_widget_set_sensitive (dialog->transport_combo, FALSE);
 
       /* we just allow closing the dialog */
-      dialog->close_button  = gtk_dialog_add_button (GTK_DIALOG (dialog),
-      						     GTK_STOCK_CLOSE,
-      						     GTK_RESPONSE_CANCEL);
+      dialog->close_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_CANCEL);
       break;
     case GDICT_SOURCE_DIALOG_CREATE:
-      dialog->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-      						     GTK_STOCK_CANCEL,
-      						     GTK_RESPONSE_CANCEL);
-      dialog->add_button    = gtk_dialog_add_button (GTK_DIALOG (dialog),
-      						     GTK_STOCK_ADD,
-      						     GTK_RESPONSE_ACCEPT);
+      dialog->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Cancel"), GTK_RESPONSE_CANCEL);
+      dialog->add_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Add"), GTK_RESPONSE_ACCEPT);
       /* the "add" button sensitivity is controlled by the transport_combo
        * since it's the only setting that makes a source usable.
        */
       gtk_widget_set_sensitive (dialog->add_button, FALSE);
       break;
     case GDICT_SOURCE_DIALOG_EDIT:
-      dialog->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog),
-      						     GTK_STOCK_CANCEL,
-      						     GTK_RESPONSE_CANCEL);
-      dialog->close_button  = gtk_dialog_add_button (GTK_DIALOG (dialog),
-		      	 			     GTK_STOCK_CLOSE,
-						     GTK_RESPONSE_CLOSE);
+      dialog->cancel_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("C_ancel"), GTK_RESPONSE_CANCEL);
+      dialog->close_button = gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_CLOSE);
       break;
     default:
       g_assert_not_reached ();
@@ -672,8 +650,6 @@ gdict_source_dialog_constructor (GType                  type,
    */
   update_dialog_ui (dialog);
   
-  gtk_widget_pop_composite_child ();
-  
   return object;
 }
 
