@@ -29,6 +29,7 @@
 #include <gtk/gtk.h>
 #include <glib.h>
 #include <glib/gi18n.h>
+#include <glib/gstdio.h>
 
 #include <libgdict/gdict.h>
 
@@ -157,6 +158,10 @@ static const gchar *toggle_actions[] = {
   "next-def",
   "first-def",
   "last-def",
+  "select-all",
+  "find",
+  "find-next",
+  "find-previous",
 };
 
 static gint n_toggle_state = G_N_ELEMENTS (toggle_actions);
@@ -789,8 +794,6 @@ gdict_window_load_state (GdictWindow *window)
 {
   gchar *state_file;
   GKeyFile *state_key;
-  gchar *data;
-  gsize data_len;
   GError *error;
 
   state_file = g_build_filename (g_get_user_cache_dir (),
@@ -1513,6 +1516,21 @@ gdict_window_link_clicked (GdictDefbox *defbox,
   g_signal_emit (window, gdict_window_signals[CREATED], 0, new_window);
 }
 
+static void
+gdict_window_defbox_selection_changed (GdictDefbox *defbox,
+                                       GdictWindow *window)
+{
+  GAction *action;
+  gboolean has_selection;
+
+  action = g_action_map_lookup_action (G_ACTION_MAP (window), "copy");
+  if (action)
+    {
+      has_selection = gdict_defbox_get_has_selection (defbox);
+      g_simple_action_set_enabled (G_SIMPLE_ACTION (action), has_selection);
+    }
+}
+
 static void
 gdict_window_drag_data_received_cb (GtkWidget        *widget,
 				    GdkDragContext   *context,
@@ -1580,16 +1598,13 @@ gdict_window_constructor (GType                  type,
 {
   GObject *object;
   GdictWindow *window;
-  gboolean is_maximized;
   GtkWidget *hbox;
   GtkWidget *handle;
   GtkWidget *frame1, *frame2;
   GtkWidget *vbox;
   GtkWidget *button;
   PangoFontDescription *font_desc;
-  gchar *font_name, *sidebar_page;
-  gboolean sidebar_visible;
-  gboolean statusbar_visible;
+  gchar *font_name;
   GtkAllocation allocation;
   
   object = G_OBJECT_CLASS (gdict_window_parent_class)->constructor (type, n_construct_properties, construct_params);
@@ -1662,6 +1677,10 @@ gdict_window_constructor (GType                  type,
   g_signal_connect (window->defbox, "link-clicked",
                     G_CALLBACK (gdict_window_link_clicked),
                     window);
+  g_signal_connect (GDICT_DEFBOX (window->defbox), "selection-changed",
+                    G_CALLBACK (gdict_window_defbox_selection_changed),
+                    window);
+  gdict_window_defbox_selection_changed (GDICT_DEFBOX (window->defbox), window);
 
   gtk_drag_dest_set (window->defbox,
   		     GTK_DEST_DEFAULT_ALL,
